@@ -1,5 +1,5 @@
 package Prometheus::Tiny::Shared;
-$Prometheus::Tiny::Shared::VERSION = '0.022';
+$Prometheus::Tiny::Shared::VERSION = '0.023';
 # ABSTRACT: A tiny Prometheus client with a shared database behind it
 
 use warnings;
@@ -25,7 +25,7 @@ EOF
   }
 
   my $filename = delete $args{filename};
-  my $init_file = delete $args{init_file} // 0;
+  my $init_file = delete $args{init_file} || 0;
 
   my $self = $class->SUPER::new(%args);
 
